@@ -139,7 +139,7 @@ g_mutex_get_impl (GMutex *mutex)
  * This function is useful to initialize a mutex that has been
  * allocated on the stack, or as part of a larger structure.
  * It is not necessary to initialize a mutex that has been
- * created that has been statically allocated.
+ * statically allocated.
  *
  * |[
  *   typedef struct {
@@ -225,7 +225,7 @@ g_mutex_unlock (GMutex *mutex)
   gint status;
 
   if G_UNLIKELY ((status = pthread_mutex_unlock (g_mutex_get_impl (mutex))) != 0)
-    g_thread_abort (status, "pthread_mutex_lock");
+    g_thread_abort (status, "pthread_mutex_unlock");
 }
 
 /**
@@ -1172,8 +1172,10 @@ void
 g_system_thread_set_name (const gchar *name)
 {
 #ifdef HAVE_SYS_PRCTL_H
+#ifdef PR_SET_NAME
   prctl (PR_SET_NAME, name, 0, 0, 0, 0);
 #endif
+#endif
 }
 
 /* {{{1 Epilogue */
